#' Ensure a file name has the intended extension.
#'
#' See [strex::str_give_ext()].
#'
#' @inheritParams strex::str_give_ext
#' @export
give_ext <- strex::str_give_ext

#' @rdname give_ext
#' @export
str_give_ext <- give_ext
